California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
COX, DAVE LEIBMAN, ROBERTO MC DONALD, KRISTINE L. SCHNEIDER, CHRISTOPHER D.
| STATE SENATE 03
FELDER, ANDREW GRIMES, IAN J. JONES, DAVY MIGDEN, CAROLE RHODES, DAVID
STATE SENATE 05
MACHADO, MICHAEL J. PODESTO, GARY
| STATE SENATE 07
TORLAKSON, TOM
STATE SENATE 09
CONDIT, TOM DEUTSCHE, PATRICIA A. PERATA, DON VON PINNON, PETER J.
| STATE SENATE 11
LEMPERT, TED RICE, ALLEN M. SIMITIAN, S. JOSEPH ZELLHOEFER, JON W.
STATE SENATE 13
ALQUIST, ELAINE CONNOLLY, SHANE PATRICK DIAZ, ANDREW G. ABE DIAZ, MANNY LAURSEN, MICHAEL V. MEDEIROS, JOSE FRANCIS WEBSTER, JOHN H.
| STATE SENATE 15
MADSEN, RYEN BROOK JUDE MALDONADO, ABEL PINARD, MARGARET ANN
STATE SENATE 17
BALLARD, JOHN KRAUT, JONATHAN DANIEL RUNNER, GEORGE C.
| STATE SENATE 19
GRABER, PAUL J. MC CLINTOCK, THOMAS
STATE SENATE 21
NEW, BOB SCOTT, JACK
| STATE SENATE 23
GOLDMAN, COLIN S. KUEHL, SHEILA J. LANZI, LEONARD MICHAEL
STATE SENATE 25
GREEN, BRENDA CAROL OGDEN, DALE F. SPENCER, JAMES A. VINCENT, EDWARD WOODS, ERNEST L.
| STATE SENATE 27
CASTELLANOS, CESAR N. JACKSON, MICHAEL A. LOWENTHAL, ALAN
STATE SENATE 29
BAUTISTA, RUFINO M. FERNANDES, FRED D. MARGETT, ROBERT
| STATE SENATE 31
DUTTON, BOB MIKELS, MARJORIE M.
STATE SENATE 33
ACKERMAN, RICHARD DAUGHERTY, RANDALL A.
| STATE SENATE 35
CAMPBELL, JOHN B.T. JOHNSON, TIMOTHY MADDOX, KENNETH SIEBERT, RITA B. SNYDER, JOSEPH
STATE SENATE 37
BATTIN JR., JAMES F. JOHANSEN, PATRICIA ANN
| STATE SENATE 39
BOURKE, KENNETH P. DENNY, RALPH ELLSWORTH GALLEY, JAMES F. KEHOE, CHRISTINE MURPHY, JOHN STIRLING, LARRY
ASSEMBLY DISTRICTS
ASSEMBLY 01
ANTON, KENNETH R. BERG, PATTY FOPPOLI, DOMINIC J. TYRONE, RAY
| ASSEMBLY 02
LA MALFA, DOUG MC IVER, BARBARA G.
ASSEMBLY 03
BURK, ROBERT C. KEENE, RICHARD J. WOODS, ROBERT A.
| ASSEMBLY 04
LESLIE, R. TIM SCHWENK, TODD W.
ASSEMBLY 05
CAREY, SANDRA A. FOX, MICHAEL A. LOREE, TIMOTHY R. MANFRE, MELISSA NIELLO, ROGER
| ASSEMBLY 06
NATION, JOE PATRICK, CAROLYN F.
ASSEMBLY 07
EVANS, NOREEN M. KRUEGER, PATRICIA "PAT" LEDDY, JIM SMITH, F. AARON
| ASSEMBLY 08
MUNN, JOHN R. WOLK, LOIS
ASSEMBLY 09
BEGAY, DONNA R. COCHRAN, LESLIE T. DICKINSON, ROGER GARCIA, GASPAR R. HAMMOND, LAUREN HERNANDEZ, MANUEL P. JONES, DAVE MORGAN, GALE R.
| ASSEMBLY 10
LANG, CULLENE NAKANISHI, ALAN S.
ASSEMBLY 11
CANCIAMILLA, JOSEPH MANSKE, FRANK J. SANTIAGO, PAUL E.
| ASSEMBLY 12
EPSTEIN, HOWARD MADEN, CHRISTOPHER R. YEE, LELAND Y.
ASSEMBLY 13
GALLAGHER, COLIN V. LENO, MARK MARVIN, JONATHAN SCOTT NEIRA, GAIL E.
| ASSEMBLY 14
HANCOCK, LONI MONTAUK, LANCE O'NEAL, KEVIN D.
ASSEMBLY 15
HOUSTON, GUY SHAW, ELAINE D.
| ASSEMBLY 16
CHAN, WILMA UDINSKY, JERALD
ASSEMBLY 17
MATTHEWS, BARBARA MC GARRY, NELLIE SANCHEZ, MOSES ARIEL SHULTS, CHARLES W. SWEET, WILLIAM RALPH JR.
| ASSEMBLY 18
COLFER, RONALD J. KLEHS, JOHAN
ASSEMBLY 19
BRINKMAN, CATHERINE S. GILSTER, MILES C. MULLIN, GENE R.
| ASSEMBLY 20
BHATT, ASHIK K. HAYASHI, DENNIS MANAYAN, HENRY C. PICO JR., THOMAS P. TORRICO, ALBERTO WILLIAMS, CLIFFORD R.
ASSEMBLY 21
BARTON, JOHN H. CARCIONE, JOHN P. NESBET, BARBARA POIZNER, STEVE RUSKIN, IRA
| ASSEMBLY 22
DOMINGUEZ-GASSON, MARIE C. LIEBER, SALLY
ASSEMBLY 23
BLOOMBERG III, WARNER S. COTO, JOE MARTINEZ-ROACH, PATRICIA NAPOLI, KATHY CHAVEZ PATROSSO, MARK TRAN, KHANH D.
| ASSEMBLY 24
COHN, REBECCA COLLIER III, ZANDER Y. JANKOWIAK, FRED KONNYU, ERNEST L. REDICK, DAVID
ASSEMBLY 25
COGDILL, DAVID E. MARKS, BRYAN JUSTIN
| ASSEMBLY 26
AGHAZARIAN, GREG WEINTZ, TIM P.
ASSEMBLY 27
BARLICH, JACK D. LAIRD, JOHN S.
| ASSEMBLY 28
PERKINS, ROBERT E. SALINAS, SIMON
ASSEMBLY 29
BRIGGS, MIKE CROCKFORD, JOHN MACIAS, MICHAEL R. MATHYS, CHRIS VILLINES, MICHAEL N.
| ASSEMBLY 30
GARDNER, M. DEAN PARRA, NICOLE
ASSEMBLY 31
ARAMBULA, JUAN BETANCOURT, PAUL WARKENTIN, STANLEY R.
| ASSEMBLY 32
ARMAS, ANTHONY M. MC CARTHY, KEVIN
ASSEMBLY 33
BLAKESLEE, SAM HUTCHINGS, THOMAS A. JENKINS, STEWART D. KIRKLAND, GARY L. KOKKONEN, MATT ZIMMERMAN, MICHAEL
| ASSEMBLY 34
FLOREZ, MAGGIE MAZE, BILL
ASSEMBLY 35
NAVA, PEDRO I. POHL, BOB
| ASSEMBLY 36
SCIONEAUX, HORTON
ASSEMBLY 37
GORELL, JEFF MC CLENDON, ERIC R. PRINCE, ADRIENNE M. ROBINSON, MIKE STRICKLAND, AUDRA
| ASSEMBLY 38
DAVIS, BRIAN JOSEPH RICHMAN, KEITH STUART
ASSEMBLY 39
AYAO, ELY DE LA CRUZ MONTANEZ, CINDY
| ASSEMBLY 40
ISLER, MARK LEVINE, LLOYD
ASSEMBLY 41
BONHACH, HEATHER PETERS KOFFLER, RICHARD P. PAVLEY, FRAN
| ASSEMBLY 42
FREDRIX, PAUL MORGAN KORETZ, PAUL
ASSEMBLY 43
FROMMER, DARIO WOREN, SANDOR J.
| ASSEMBLY 44
GABRIEL, LYNN LIU, CAROL WILCOX, DAVID C.
ASSEMBLY 45
GOLDBERG, JACKIE GUTIERREZ, OSCAR A.
| ASSEMBLY 46
ALDANA JR., MANUEL NUNEZ, FABIAN
ASSEMBLY 47
BASS, KAREN COOPER, DAVID A. DE BAETS, PETER D. EVERETT, DALE V. GROPER, RICHARD P. HOLDEN, NATE IVIE, RICKEY
| ASSEMBLY 48
ALEXANDER, SEBASTIAN RIDLEY-THOMAS, MARK
ASSEMBLY 49
BROWN, LAURA G. CHU, JUDY NEEDS, SANDRA L.
| ASSEMBLY 50
CHACON, HECTOR DE LA TORRE, HECTOR MENDEZ, JUAN CARLOS MILLER, GLADYS O. REYES, XAVIER
ASSEMBLY 51
HORTON, JEROME E. SHERMAN, DANIEL R.
| ASSEMBLY 52
DYMALLY, MERVYN M.
ASSEMBLY 53
BOIVIE, ETHAN M. GORDON, MIKE HILL, GREGORY CHARLES SMITH, JAMES R.
| ASSEMBLY 54
KARNETTE, BETTY KUYKENDALL, STEVEN T. STERNE, JOHN HOWARD
ASSEMBLY 55
OROPEZA, JENNY UNDERHILL, MARGHERITA
| ASSEMBLY 56
BERMUDEZ, RUDY BRANTUK, JOHN W.
ASSEMBLY 57
CHAVEZ, EDWARD "ED" VALENZUELA, VICTOR M.
| ASSEMBLY 58
CALDERON, RONALD TOPALIAN, RITA H.
ASSEMBLY 59
HARDEN, DANIEL V. MOUNTJOY, DENNIS WARD, FRITZ R.
| ASSEMBLY 60
HUFF, ROBERT 'BOB' MAC ALONEY, WILLIAM MARTINEZ, PATRICK JOHN PACHECO, GAYLE E.
ASSEMBLY 61
MC LEOD, GLORIA NEGRETE MOORE, SHIRLEY R. WAPNER, ALAN D.
| ASSEMBLY 62
BACA JR., JOE HAWKINS, WALTER S. MENDOZA-WARE, MARGE PRUITT, DAVID ROA
ASSEMBLY 63
EMMERSON, BILL KEEDY, MAUREEN K. LYON, GEOFFREY MC NAMEE, D'ANDRE MORRELL, MIKE PIROZZI, ELIA V. ROBLES, SYLVIA A. STAVROS, SAM
| ASSEMBLY 64
BENOIT, JOHN J. MELSH, ROBERT J.
ASSEMBLY 65
BOGH, RUSSELL V. RAMIREZ-DEAN, RITA
| ASSEMBLY 66
HAYNES, RAYMOND N. LEE, JACK N. NICHOLSON, LAUREL A.
ASSEMBLY 67
SILVA, DAVID P. WESTWELL, NORM S.
| ASSEMBLY 68
LEYES, MARK A. SNOOK, AL TRAN, VAN
ASSEMBLY 69
ALVAREZ, CLAUDIA BADE, OTTO R. REIS, GEORGE ROSS, REUBEN A.
| ASSEMBLY 70
BALDWIN, MARK CRISTICH, CRISTI L. DE VORE, CHARLES S. GUPTA, CHONCHOL D. MARIZ, CARL L. PHAM, LONG K. WAGNER, DON ZIPPI, MARIANNE
ASSEMBLY 71
FOSTER, BEA SPITZER, TODD
| ASSEMBLY 72
CROSS, BRIAN LEE DAUCHER, LYNN JOHNSON, ROSS W.
ASSEMBLY 73
CALZADA, KATHLEEN FAVOR, ANDREW H. GIBSON, JAMES E. WALTERS, MIMI WILSON, THOMAS W.
| ASSEMBLY 74
KING, PAUL H. UNDERWOOD, KAREN WYLAND, MARK B.
ASSEMBLY 75
HEUMANN, KAREN A PLESCIA, GEORGE A. SENECAL, RICHARD J.
| ASSEMBLY 76
HALL, VINCE HENRY HUNTER, TRICIA RAE OSBORNE, JENNIFER SALDANA, LORI STAMPS, BILL VON SZELISKI, HEIDI J.
ASSEMBLY 77
HALL, VIRGIL R. LA SUER, JAY LARKIN, CHRISTOPHER
| ASSEMBLY 78
DAVIS, PATRICIA S. HALE, JOSH HORTON, SHIRLEY RICASA, ARLIE SHERARD, MAXINE J.
ASSEMBLY 79
CONROE, ELI W. VARGAS, JUAN C.
| ASSEMBLY 80
ANDREAS, MARY ANN GARCIA, BONNIE